/*********
  Juist board kiezen in Arduino (hier Wemos D1 mini)
  Uitlezen DHT22 en daarna naar MySQL uploaden
  Opgelet, configuratie file MySQL aanpassen zodat MySQL remote te benaderen is
  sudo nano /etc/mysql/my.cnf, IP 127.0.0.1 naar juist IP adres veranderen !
  Volgende instellingen zijn nodig : 
  IP-adres van de server waar MySQL op draait (kan lokaal zijn)
  IP-adres van Wemos (je kan ook DHCP gebruiken, router geeft dan een IP-adres)
  SSID en paswoord van het Wifi netwerk dat je wil gebruiken
  User met schrijfrechten voor MySQL (moet ook ingesteld worden in MySQL)
  Database, tabel en benaming ook instellen in MySQL
*********/
#include <MySQL_Connection.h>
#include <MySQL_Cursor.h>
// Including the ESP8266 WiFi library
#include <ESP8266WiFi.h>
#include "DHT.h"
// Oled screen over I2C
#include <Wire.h>  // Include Wire if you're using I2C
#include <SFE_MicroOLED.h>  // Include the SFE_MicroOLED library
#define PIN_RESET 255  //
#define DC_JUMPER 0  // I2C Addres: 0 - 0x3C, 1 - 0x3D
//////////////////////////////////
// MicroOLED Object Declaration //
//////////////////////////////////
MicroOLED oled(PIN_RESET, DC_JUMPER);  // I2C Example
// Uncomment one of the lines below for whatever DHT sensor type you're using!
//#define DHTTYPE DHT11   // DHT 11
//#define DHTTYPE DHT21   // DHT 21 (AM2301)
#define DHTTYPE DHT22   // DHT 22  (AM2302), AM2321

// Replace with your network details
const char* ssid = "SSID";
const char* password = "password";

WiFiClient client;
MySQL_Connection conn((Client *)&client);
char INSERT_SQL[] = "USE metingen; INSERT INTO `Temperatuur`(`Temperatuur_1`, `Hygro`) VALUES (%s,%s)";
char query[128];

IPAddress server_addr(192,168,0,25);          // MySQL server IP
char user[] = "Wemos";           // MySQL user
char mysql_password[] = "Wemos";       // MySQL password

// Web Server on port 80
WiFiServer server(80);

// DHT Sensor
const int DHTPin = D4;
// Initialize DHT sensor.
DHT dht(DHTPin, DHTTYPE);
float t,h,f;
// Temporary variables
static char celsiusTemp[7];
static char humidityTemp[7];
//for measuring interval
unsigned long currentMillis = 60*1000;
unsigned long previousMillis = 0;        // will store last time temp was updated
unsigned long lastMillis = 0;        // will store last time temp was updated 
unsigned long deepsleepMillis = 0; 
// constants won't change :
const long interval = 10000;           // interval at which to measure (milliseconds)
const long database_interval =60*1000;           // interval at which to measure (milliseconds) 
// only runs once on boot
void setup() {
// Initializing serial port for debugging purposes
Serial.begin(115200);
delay(10);
oled.begin();
delay(100);
oled.clear(ALL);
oled.display();  
int SCREEN_WIDTH = oled.getLCDWidth();
int SCREEN_HEIGHT = oled.getLCDHeight();
dht.begin();
  
// Connecting to WiFi network
Serial.println();
Serial.print("Connecting to ");
Serial.println(ssid);
IPAddress ip(192, 168,0,26);
IPAddress gateway(192, 168, 0, 1);
IPAddress subnet(255, 255, 255, 0); 
WiFi.config(ip, gateway, subnet);
WiFi.forceSleepWake(); //anders werkt wifi niet na deepsleep ????
WiFi.begin(ssid, password);
  
while (WiFi.status() != WL_CONNECTED) {
    delay(250);
    Serial.print(".");
  }
Serial.println("");
Serial.println("WiFi connected");
Serial.print("   OK  ");
Serial.print("Module IP: ");
Serial.println(WiFi.localIP());
// Starting the web server
server.begin();
Serial.println("Web server running. Waiting for the ESP IP...");
delay(10);
}

// runs over and over again
void loop() {
  //measure every 10 seconds
  
  if (currentMillis - previousMillis >= interval) {
         Serial.print("Start ");
        previousMillis = currentMillis;
         // Reading temperature or humidity takes about 250 milliseconds!
        h = dht.readHumidity();
        dtostrf(h, 6, 2, celsiusTemp); 
        // Read temperature as Celsius (the default)
        t = dht.readTemperature();
         dtostrf(t, 6, 2, humidityTemp); 
         Serial.print("Hum: ");
         Serial.print(h);
         Serial.print(" %\t Temp: ");
         Serial.print(t);
         Serial.println(" *C ");
        
         oled.setFontType(0);  // Set the text to small (10 columns, 6 rows worth of characters).
        //oled.setFontType(1);  // Set the text to medium (6 columns, 3 rows worth of characters).
        //oled.setFontType(2);  // Set the text to medium/7-segment (5 columns, 3 rows worth of characters).
        //oled.setFontType(3);  // Set the text to large (5 columns, 1 row worth of characters).
        oled.clear(PAGE);
        oled.setCursor(0, 0);  // Set the text cursor to the top of the screen.
        oled.print("Temperatur"); // Print a const string
        oled.setFontType(1); 
        oled.print(t);
        oled.setFontType(0);
        oled.setCursor(0, 23);  // Set the text cursor to the middel of the screen.
        oled.print("Humidity :");
        oled.setFontType(1);
        oled.print(h);
        oled.display(); // Draw to the screen
      }


if (currentMillis - lastMillis >= database_interval) {
        lastMillis = currentMillis;              
        Serial.println("Connecting to database");
        while (conn.connect(server_addr, 3306, user, mysql_password) != true) {
        delay(200);
        Serial.print ( "." );
          }
        int hygro=h; int tem=t;
        Serial.println("");
        Serial.println("Connected to SQL Server!"); 
       // sprintf(query, INSERT_SQL, tem, hygro);
        sprintf(query, INSERT_SQL, celsiusTemp, humidityTemp);  
        Serial.println("Recording data.");
        Serial.println(query);
        MySQL_Cursor *cur_mem = new MySQL_Cursor(&conn);
        cur_mem->execute(query);
        delete cur_mem;              
        }
 currentMillis = millis(); 
 Serial.println("Client disconnected, going to sleep for 60 sec.");
    oled.clear(PAGE);
    oled.display(); // Draw to the screen
    oled.setFontType(0);
    oled.setCursor(0, 0);  // Set the text cursor to the top of the screen.
    oled.print("Go to sleep"); // Print a const string
    oled.setCursor(0, 23);  // Set the text cursor to the middel of the screen.
    oled.print("now for 30 min");
    oled.display(); // Draw to the screen
    delay(1000);
    oled.clear(PAGE);
    oled.display(); // Draw to the screen
    deepsleepMillis=60000000*30-millis()*1000+62.4*1000000;//gemiddeld 62.4 sek te snel terug wakker op 30 min !!
    ESP.deepSleep(deepsleepMillis,WAKE_RF_DEFAULT);
    delay(100);

}  



